@@ -1,4 +1,4 @@
-from svarga.utils.opster import command
+from opster import command
 
 from svargaext import clevercss
 
